@@ -239,6 +239,34 @@ class get_app_samePubApp(get_app_appinfo):
                 self.app_class_genid = info['class']['brand']
                 return self.app_total_genid, self.app_class_genid
 
+# 获取关键词的相关数据；
+class get_keyword_info:
+    def __init__(self, keyword, run_time=datetime.date.today(), version='ios12', country='cn', device='iphone', search_type='all'):
+        self.keyword = keyword
+        self.run_time = run_time
+        self.version = version
+        self.country = country
+        self.device = device
+        self.search_type = search_type
+        self.one_day = datetime.timedelta(days=1)
+
+    def get_keyword_search(self):
+        url = 'https://api.qimai.cn/search/index?device=%s&country=%s&search=%s&version=%s&date=%s&search_type=%s&edate=%s' %(self.device, self.country, self.keyword, self.version, self.run_time, self.search_type, self.run_time-self.one_day)
+        res = session.get(url, headers=headers)
+        self.keyword_serch_index = res.json()
+        return self.keyword_serch_index
+
+    def get_keyword_WordInfo(self):
+        url = 'https://api.qimai.cn/search/getWordInfo?device=%s&country=%s&search=%s&version=%s&date=%s&search_type=%s&edate=%s' %(self.device, self.country, self.keyword, self.version, self.run_time, self.search_type, self.run_time-self.one_day)
+        res = session.get(url, headers=headers)
+        self.keyword_WordInfo = res.json()
+        return self.keyword_WordInfo
+
+    def get_keyword_hints(self):
+        self.get_keyword_WordInfo()
+        self.hints = self.keyword_WordInfo['wordInfo']['hints']
+        return self.hints
+
 # 获取产品的关键词相关数据；
 class get_app_keyword:
     def __init__(self, appid, run_time):
@@ -266,6 +294,12 @@ class get_app_keyword:
         self.app_AnalysisDataKeyword = res.json()
         return self.app_AnalysisDataKeyword
 
+    def get_keywordDetail_to_df(self):
+        self.get_keywordDetail()
+        self.json_df = json_normalize(self.app_keywordDetail['data'])
+        self.json_df.columns = ['关键词ID', '关键词', '排名', '变动前排名', '排名变动值', '指数', '结果数', '未知1', '未知2']
+        return self.json_df
+
 # 获取产品评论的相关接口；
 class get_app_comment:
     def __init__(self, appid, start_time, end_time, typec='day', star='five'):
