@@ -10,10 +10,10 @@ class get_top_keyword:
         self.end_time = datetime.date.fromisoformat(end_time)
         self.one_day = datetime.timedelta(days=1)
 
-    def df_to_excel(self):
+    def df_to_excel(self, file_path='./'):
         df = self.get_all_top()
         df.to_excel(
-            './%s_%s_Top关键词数据.xlsx' % (self.end_time, self.app_name), encoding='utf-8-sig', index=False
+            '%s%s_%s_Top关键词数据.xlsx' % (file_path, self.end_time, self.app_name), encoding='utf-8-sig', index=False
         )
 
     def get_all_top(self):
@@ -70,10 +70,10 @@ class get_top_keyword:
 
 
 class get_multiple_top_keyword():
-    def __init__(self, appid_list, keyword_hot_start, start_time, end_time):
+    def __init__(self, appid_list, keyword_hot_start, start_time, end_time, file_path='./'):
         for appid in appid_list:
             app_name = get_app_appinfo(appid).get_subname()
             df = get_top_keyword(appid, keyword_hot_start, start_time, end_time).get_all_top()
             df.to_excel(
-                './%s_%s_Top关键词数据.xlsx' %(end_time, app_name), encoding='utf-8-sig', index=False
+                '%s%s_%s_Top关键词数据.xlsx' %(file_path, end_time, app_name), encoding='utf-8-sig', index=False
             )
\ No newline at end of file
